/*
 * Copyright 2015 Andrew T. Flowers, K0SM
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package dopplerpsk.dsp;

import java.util.HashMap;

/**
 * Class for mapping chars to varicode.
 * 
 * @author Andrew T. Flowers
 */
public class Varicode {

    private static final HashMap<String, String> m = new HashMap();

    static {

        m.put("\f", "11101");
        m.put("\r", "11111");
        m.put(" ", "1");
        m.put("!", "111111111");
        m.put("\"", "101011111");
        m.put("#", "111110101");
        m.put("$", "111011011");
        m.put("%", "1011010101");
        m.put("&", "1010111011");
        m.put("'", "101111111");
        m.put("(", "11111011");
        m.put(")", "11110111");
        m.put("*", "101101111");
        m.put("+", "111011111");
        m.put(",", "1110101");
        m.put("-", "110101");
        m.put(".", "1010111");
        m.put("/", "110101111");
        m.put("0", "10110111");
        m.put("1", "10111101");
        m.put("2", "11101101");
        m.put("3", "11111111");
        m.put("4", "101110111");
        m.put("5", "101011011");
        m.put("6", "101101011");
        m.put("7", "110101101");
        m.put("8", "110101011");
        m.put("9", "110110111");
        m.put(":", "11110101");
        m.put(";", "110111101");
        m.put("<", "111101101");
        m.put("=", "1010101");
        m.put(">", "111010111");
        m.put("?", "1010101111");
        m.put("@", "1010111101");
        m.put("A", "1111101");
        m.put("B", "11101011");
        m.put("C", "10101101");
        m.put("D", "10110101");
        m.put("E", "1110111");
        m.put("F", "11011011");
        m.put("G", "11111101");
        m.put("H", "101010101");
        m.put("I", "1111111");
        m.put("J", "111111101");
        m.put("K", "101111101");
        m.put("L", "11010111");
        m.put("M", "10111011");
        m.put("N", "11011101");
        m.put("O", "10101011");
        m.put("P", "11010101");
        m.put("Q", "111011101");
        m.put("R", "10101111");
        m.put("S", "1101111");
        m.put("T", "1101101");
        m.put("U", "101010111");
        m.put("V", "110110101");
        m.put("W", "101011101");
        m.put("X", "101110101");
        m.put("Y", "101111011");
        m.put("Z", "1010101101");
        m.put("[", "111110111");
        m.put("\\", "111101111");
        m.put("]", "111111011");
        m.put("^", "1010111111");
        m.put("_", "101101101");
        m.put("`", "1011011111");
        m.put("a", "1011");
        m.put("b", "1011111");
        m.put("c", "101111");
        m.put("d", "101101");
        m.put("e", "11");
        m.put("f", "111101");
        m.put("g", "1011011");
        m.put("h", "101011");
        m.put("i", "1101");
        m.put("j", "111101011");
        m.put("k", "10111111");
        m.put("l", "11011");
        m.put("m", "111011");
        m.put("n", "1111");
        m.put("o", "111");
        m.put("p", "111111");
        m.put("q", "110111111");
        m.put("r", "10101");
        m.put("s", "10111");
        m.put("t", "101");
        m.put("u", "110111");
        m.put("v", "1111011");
        m.put("w", "1101011");
        m.put("x", "11011111");
        m.put("y", "1011101");
        m.put("z", "111010101");
        m.put("{", "1010110111");
        m.put("|", "110111011");
        m.put("}", "1010110101");
        m.put("~", "1011010111");

    }

    /**
     * Special char for IDLE (continuous phase reversals.
     */
    public static final String IDLE = "0";
    
    /**
     * Special char for sending a steady carrier.
     */
    public static final String CARRIER = "1";

    /**
     * Returns the varicode pattern for the supplied character, plus
     * the trailing "00" for the character space.
     * @param s
     * @return 
     */
    public static String getPattern(char c) {
        return getPattern("" + c);  //make it a string
    }

    /**
     * Returns the varicode pattern for the supplied character, plus
     * the trailing "00" for the character space.
     * @param s
     * @return 
     */
    public static String getPattern(String s) {
        if (s == null) {
            return IDLE;
        }
        String rVal = m.get(s);
        if (s == null) {
            rVal = m.get("?");
        }
        return rVal + "00";  //add charspace to end
    }
}
